@@ -60,6 +60,7 @@ def index():
     elif request.vars.password:
         if verify_password(request.vars.password):
             session.authorized = True
+            login_record(True)
 
             if CHECK_VERSION:
                 session.check_version = True
@@ -72,8 +73,15 @@ def index():
 
             redirect(send)
         else:
-            response.flash = T('invalid password')
-
+            times_denied = login_record(False)
+            if times_denied >= allowed_number_of_attempts:
+                response.flash = \
+                    T('admin disabled because too many invalid login attempts')
+            elif times_denied == allowed_number_of_attempts - 1:
+                response.flash = \
+                    T('You have one more login attempt before you are locked out')
+            else:
+                response.flash = T('invalid password.')
     return dict(send=send)
 
 
@@ -580,8 +588,8 @@ def resolve():
             return 'minus'
 
     if request.vars:
-        c = ''.join([item[2:] for (i, item) in enumerate(d) if item[0] \
-                     == ' ' or 'line%i' % i in request.vars])
+        c = '\n'.join([item[2:].rstrip() for (i, item) in enumerate(d) if item[0] \
+                           == ' ' or 'line%i' % i in request.vars])
         safe_write(path, c)
         session.flash = 'files merged'
         redirect(URL('edit', args=request.args))
@@ -702,8 +710,8 @@ def design():
         functions[c] = items
 
     # Get all views
-    views = sorted(listdir(apath('%s/views/' % app, r=request), '[\w/\-]+\.\w+$'))
-    views = [x.replace('\\','/') for x in views]
+    views = sorted(listdir(apath('%s/views/' % app, r=request), '[\w/\-]+(\.\w+)+$'))
+    views = [x.replace('\\','/') for x in views if not x.endswith('.bak')]
     extend = {}
     include = {}
     for c in views:
@@ -1184,7 +1192,7 @@ def update_languages():
     app = get_app()
     update_all_languages(apath(app, r=request))
     session.flash = T('Language files (static strings) updated')
-    redirect(URL('design',args=app))
+    redirect(URL('design',args=app,anchor='languages'))
 
 def twitter():
     session.forget()
@@ -1209,6 +1217,7 @@ def user():
         return dict(form=T("Disabled"))
 
 def reload_routes():
-   """ Reload routes.py """
-   gluon.rewrite.load()
-   redirect(URL('site'))
+    """ Reload routes.py """
+    import gluon.rewrite
+    gluon.rewrite.load()
+    redirect(URL('site'))
