@@ -171,7 +171,7 @@
 'You are successfully running web2py': 'web2by wird erfolgreich ausgeführt',
 'You can modify this application and adapt it to your needs': 'Sie können diese Anwendung verändern und Ihren Bedürfnissen anpassen',
 'You visited the url': 'Sie besuchten die URL',
-'about': 'Über',
+'About': 'Über',
 'additional code for your application': 'zusätzlicher Code für Ihre Anwendung',
 'admin disabled because no admin password': ' admin ist deaktiviert, weil kein Admin-Passwort gesetzt ist',
 'admin disabled because not supported on google apps engine': 'admin ist deaktiviert, es existiert dafür keine Unterstützung auf der google apps engine',
@@ -192,20 +192,20 @@
 'call': 'call',
 'cannot create file': 'Kann Datei nicht erstellen',
 'cannot upload file "%(filename)s"': 'Kann Datei nicht Hochladen "%(filename)s"',
-'change admin password': 'Administrator-Passwort ändern',
+'Change admin password': 'Administrator-Passwort ändern',
 'change password': 'Passwort ändern',
 'check all': 'alles auswählen',
-'check for upgrades': 'check for upgrades',
-'clean': 'löschen',
+'Check for upgrades': 'check for upgrades',
+'Clean': 'löschen',
 'click here for online examples': 'hier klicken für online Beispiele',
 'click here for the administrative interface': 'hier klicken für die Administrationsoberfläche ',
 'click to check for upgrades': 'hier klicken um nach Upgrades zu suchen',
 'code': 'code',
 'collapse/expand all': 'collapse/expand all',
-'compile': 'kompilieren',
+'Compile': 'kompilieren',
 'compiled application removed': 'kompilierte Anwendung gelöscht',
 'controllers': 'Controllers',
-'create': 'erstellen',
+'Create': 'erstellen',
 'create file with filename:': 'erzeuge Datei mit Dateinamen:',
 'create new application:': 'erzeuge neue Anwendung:',
 'created by': 'created by',
@@ -222,18 +222,18 @@
 'delete': 'löschen',
 'delete all checked': 'lösche alle markierten',
 'delete plugin': 'Plugin löschen',
-'deploy': 'deploy',
+'Deploy': 'deploy',
 'design': 'design',
 'direction: ltr': 'direction: ltr',
 'documentation': 'Dokumentation',
 'done!': 'fertig!',
 'download layouts': 'download layouts',
 'download plugins': 'download plugins',
-'edit': 'bearbeiten',
+'Edit': 'bearbeiten',
 'edit controller': 'Bearbeite Controller',
 'edit profile': 'bearbeite Profil',
 'edit views:': 'Views bearbeiten:',
-'errors': 'Fehler',
+'Errors': 'Fehler',
 'escape': 'escape',
 'export as csv file': 'Exportieren als CSV-Datei',
 'exposes': 'stellt zur Verfügung',
@@ -250,13 +250,13 @@
 'file saved on %s': 'Datei gespeichert auf %s',
 'files': 'files',
 'filter': 'filter',
-'help': 'Hilfe',
+'Help': 'Hilfe',
 'htmledit': 'htmledit',
 'includes': 'Einfügen',
 'index': 'index',
 'insert new': 'neu einfügen',
 'insert new %s': 'neu einfügen %s',
-'install': 'installieren',
+'Install': 'installieren',
 'internal error': 'interner Fehler',
 'invalid password': 'Ungültiges Passwort',
 'invalid request': 'ungültige Anfrage',
@@ -267,7 +267,7 @@
 'loading...': 'lade...',
 'located in the file': 'located in Datei',
 'login': 'anmelden',
-'logout': 'abmelden',
+'Logout': 'abmelden',
 'lost password?': 'Passwort vergessen?',
 'merge': 'verbinden',
 'models': 'Modelle',
@@ -278,9 +278,9 @@
 'or import from csv file': 'oder importieren von cvs Datei',
 'or provide app url:': 'oder geben Sie eine Anwendungs-URL an:',
 'or provide application url:': 'oder geben Sie eine Anwendungs-URL an:',
-'overwrite installed app': 'installierte Anwendungen überschreiben',
-'pack all': 'verpacke alles',
-'pack compiled': 'Verpacke kompiliert',
+'Overwrite installed app': 'installierte Anwendungen überschreiben',
+'Pack all': 'verpacke alles',
+'Pack compiled': 'Verpacke kompiliert',
 'pack plugin': 'Plugin verpacken',
 'please wait!': 'bitte warten!',
 'plugins': 'plugins',
@@ -289,16 +289,16 @@
 'record does not exist': 'Datensatz existiert nicht',
 'record id': 'Datensatz id',
 'register': 'Registrierung',
-'remove compiled': 'kompilat gelöscht',
+'Remove compiled': 'kompilat gelöscht',
 'restore': 'wiederherstellen',
 'revert': 'zurückkehren',
 'save': 'sichern',
 'selected': 'ausgewählt(e)',
 'session expired': 'Sitzung Abgelaufen',
 'shell': 'shell',
-'site': 'Seite',
+'Site': 'Seite',
 'some files could not be removed': 'einige Dateien konnten nicht gelöscht werden',
-'start wizard': 'start wizard',
+'Start wizard': 'start wizard',
 'state': 'Status',
 'static': 'statische Dateien',
 'submit': 'Absenden',
@@ -321,7 +321,7 @@
 'unable to parse csv file': 'analysieren der cvs Datei nicht möglich',
 'unable to uninstall "%s"': 'deinstallieren von "%s" nicht möglich',
 'uncheck all': 'alles demarkieren',
-'uninstall': 'deinstallieren',
+'Uninstall': 'deinstallieren',
 'update': 'aktualisieren',
 'update all languages': 'aktualisiere alle Sprachen',
 'upgrade web2py now': 'jetzt web2py upgraden',
