@@ -118,7 +118,7 @@
 'Views': 'Vues',
 'Web Framework': 'Web Framework',
 'YES': 'OUI',
-'about': 'à propos',
+'About': 'à propos',
 'additional code for your application': 'code supplémentaire pour votre application',
 'admin disabled because no admin password': 'admin désactivé car aucun mot de passe admin',
 'admin disabled because not supported on google app engine': 'admin désactivé car non pris en charge sur Google Apps engine',
@@ -138,17 +138,17 @@
 'cache, errors and sessions cleaned': 'cache, erreurs et sessions nettoyé',
 'cannot create file': 'ne peu pas créer de fichier',
 'cannot upload file "%(filename)s"': 'ne peu pas charger le fichier "%(filename)s"',
-'change admin password': 'change admin password',
+'Change admin password': 'change admin password',
 'check all': 'tous vérifier ',
-'check for upgrades': 'check for upgrades',
-'clean': 'nettoyer',
+'Check for upgrades': 'check for upgrades',
+'Clean': 'nettoyer',
 'click to check for upgrades': 'Cliquez pour vérifier les mises à niveau',
 'code': 'code',
 'collapse/expand all': 'collapse/expand all',
-'compile': 'compiler',
+'Compile': 'compiler',
 'compiled application removed': 'application compilée enlevé',
 'controllers': 'contrôleurs',
-'create': 'create',
+'Create': 'create',
 'create file with filename:': 'créer un fichier avec nom de fichier:',
 'create new application:': 'créer une nouvelle application:',
 'created by': 'créé par',
@@ -164,17 +164,17 @@
 'delete': 'supprimer',
 'delete all checked': 'supprimer tout ce qui est cocher',
 'delete plugin': ' supprimer plugin',
-'deploy': 'deploy',
+'Deploy': 'deploy',
 'design': 'conception',
 'direction: ltr': 'direction: ltr',
 'docs': 'docs',
 'done!': 'fait!',
 'download layouts': 'download layouts',
 'download plugins': 'download plugins',
-'edit': 'modifier',
+'Edit': 'modifier',
 'edit controller': 'modifier contrôleur',
 'edit views:': 'edit views:',
-'errors': 'erreurs',
+'Errors': 'erreurs',
 'export as csv file': 'exportation au format CSV',
 'exposes': 'expose',
 'exposes:': 'exposes:',
@@ -191,13 +191,13 @@
 'file saved on %s': 'fichier enregistré le %s',
 'files': 'files',
 'filter': 'filter',
-'help': 'aide',
+'Help': 'aide',
 'htmledit': 'edition html',
 'includes': 'inclus',
 'index': 'index',
 'insert new': 'insérer nouveau',
 'insert new %s': 'insérer nouveau %s',
-'install': 'install',
+'Install': 'install',
 'internal error': 'erreur interne',
 'invalid password': 'mot de passe invalide',
 'invalid request': 'Demande incorrecte',
@@ -206,7 +206,7 @@
 'languages': 'langues',
 'loading...': 'Chargement ...',
 'login': 'connexion',
-'logout': 'déconnexion',
+'Logout': 'déconnexion',
 'merge': 'fusionner',
 'models': 'modèles',
 'modules': 'modules',
@@ -218,9 +218,9 @@
 'or import from csv file': 'ou importer depuis un fichier CSV ',
 'or provide app url:': 'or provide app url:',
 'or provide application url:': "ou fournir l'URL de l'application:",
-'overwrite installed app': 'overwrite installed app',
-'pack all': 'tout empaqueter',
-'pack compiled': 'paquet compilé',
+'Overwrite installed app': 'overwrite installed app',
+'Pack all': 'tout empaqueter',
+'Pack compiled': 'paquet compilé',
 'pack plugin': 'paquet plugin',
 'password changed': 'password changed',
 'plugin "%(plugin)s" deleted': 'plugin "%(plugin)s" supprimé',
@@ -229,16 +229,16 @@
 'record': 'entrée',
 'record does not exist': "l'entrée n'existe pas",
 'record id': 'id entrée',
-'remove compiled': 'retirer compilé',
+'Remove compiled': 'retirer compilé',
 'restore': 'restaurer',
 'revert': 'revenir',
 'save': 'sauver',
 'selected': 'sélectionnés',
 'session expired': 'la session a expiré ',
 'shell': 'shell',
-'site': 'site',
+'Site': 'site',
 'some files could not be removed': 'certains fichiers ne peuvent pas être supprimés',
-'start wizard': 'start wizard',
+'Start wizard': 'start wizard',
 'state': 'état',
 'static': 'statiques',
 'submit': 'envoyer',
@@ -259,7 +259,7 @@
 'unable to uninstall "%s"': 'impossible de désinstaller "%s"',
 'unable to upgrade because "%s"': 'unable to upgrade because "%s"',
 'uncheck all': 'tout décocher',
-'uninstall': 'désinstaller',
+'Uninstall': 'désinstaller',
 'update': 'mettre à jour',
 'update all languages': 'mettre à jour toutes les langues',
 'upgrade now': 'upgrade now',
