@@ -151,7 +151,7 @@
 'Views': 'Visões',
 'Welcome to web2py': 'Bem-vindo ao web2py',
 'YES': 'SIM',
-'about': 'sobre',
+'About': 'sobre',
 'additional code for your application': 'código adicional para sua aplicação',
 'admin disabled because no admin password': ' admin desabilitado por falta de senha definida',
 'admin disabled because not supported on google app engine': 'admin dehabilitado, não é soportado no GAE',
@@ -171,10 +171,10 @@
 'cache, errors and sessions cleaned': 'cache, erros e sessões eliminadas',
 'cannot create file': 'Não é possível criar o arquivo',
 'cannot upload file "%(filename)s"': 'não é possível fazer upload do arquivo "%(filename)s"',
-'change admin password': 'mudar senha de administrador',
+'Change admin password': 'mudar senha de administrador',
 'check all': 'marcar todos',
-'check for upgrades': 'checar por atualizações',
-'clean': 'limpar',
+'Check for upgrades': 'checar por atualizações',
+'Clean': 'limpar',
 'click here for online examples': 'clique para ver exemplos online',
 'click here for the administrative interface': 'Clique aqui para acessar a interface administrativa',
 'click to check for upgrades': 'clique aqui para checar por atualizações',
@@ -182,10 +182,10 @@
 'code': 'código',
 'collapse/expand all': 'collapse/expand all',
 'commit (mercurial)': 'commit (mercurial)',
-'compile': 'compilar',
+'Compile': 'compilar',
 'compiled application removed': 'aplicação compilada removida',
 'controllers': 'controladores',
-'create': 'criar',
+'Create': 'criar',
 'create file with filename:': 'criar um arquivo com o nome:',
 'create new application:': 'nome da nova aplicação:',
 'created by': 'criado por',
@@ -202,16 +202,16 @@
 'delete': 'apagar',
 'delete all checked': 'apagar marcados',
 'delete plugin': 'apagar plugin',
-'deploy': 'publicar',
+'Deploy': 'publicar',
 'design': 'modificar',
 'direction: ltr': 'direção: ltr',
 'done!': 'feito!',
 'download layouts': 'download layouts',
 'download plugins': 'download plugins',
-'edit': 'editar',
+'Edit': 'editar',
 'edit controller': 'editar controlador',
 'edit views:': 'editar visões:',
-'errors': 'erros',
+'Errors': 'erros',
 'export as csv file': 'exportar como arquivo CSV',
 'exposes': 'expõe',
 'extends': 'estende',
@@ -228,13 +228,13 @@
 'file saved on %s': 'arquivo salvo em %s',
 'files': 'files',
 'filter': 'filter',
-'help': 'ajuda',
+'Help': 'ajuda',
 'htmledit': 'htmledit',
 'includes': 'inclui',
 'insert new': 'inserir novo',
 'insert new %s': 'inserir novo %s',
 'inspect attributes': 'inspect attributes',
-'install': 'instalar',
+'Install': 'instalar',
 'internal error': 'erro interno',
 'invalid password': 'senha inválida',
 'invalid request': 'solicitação inválida',
@@ -245,7 +245,7 @@
 'loading...': 'carregando...',
 'locals': 'locals',
 'login': 'inicio de sessão',
-'logout': 'finalizar sessão',
+'Logout': 'finalizar sessão',
 'manage': 'gerenciar',
 'merge': 'juntar',
 'models': 'modelos',
@@ -258,9 +258,9 @@
 'or import from csv file': 'ou importar de um arquivo CSV',
 'or provide app url:': 'ou forneça a url de uma aplicação:',
 'or provide application url:': 'ou forneça a url de uma aplicação:',
-'overwrite installed app': 'sobrescrever aplicação instalada',
-'pack all': 'criar pacote',
-'pack compiled': 'criar pacote compilado',
+'Overwrite installed app': 'sobrescrever aplicação instalada',
+'Pack all': 'criar pacote',
+'Pack compiled': 'criar pacote compilado',
 'pack plugin': 'empacotar plugin',
 'password changed': 'senha alterada',
 'plugin "%(plugin)s" deleted': 'plugin "%(plugin)s" eliminado',
@@ -269,7 +269,7 @@
 'record': 'registro',
 'record does not exist': 'o registro não existe',
 'record id': 'id do registro',
-'remove compiled': 'eliminar compilados',
+'Remove compiled': 'eliminar compilados',
 'request': 'request',
 'response': 'response',
 'restore': 'restaurar',
@@ -279,9 +279,9 @@
 'session': 'session',
 'session expired': 'sessão expirada',
 'shell': 'Terminal',
-'site': 'site',
+'Site': 'site',
 'some files could not be removed': 'alguns arquicos não puderam ser removidos',
-'start wizard': 'iniciar assistente',
+'Start wizard': 'iniciar assistente',
 'state': 'estado',
 'static': 'estáticos',
 'submit': 'enviar',
@@ -302,7 +302,7 @@
 'unable to uninstall "%s"': 'não é possível instalar "%s"',
 'unable to upgrade because "%s"': 'não é possível atualizar porque "%s"',
 'uncheck all': 'desmarcar todos',
-'uninstall': 'desinstalar',
+'Uninstall': 'desinstalar',
 'update': 'atualizar',
 'update all languages': 'atualizar todas as linguagens',
 'upgrade web2py now': 'atualize o web2py agora',
