@@ -7,26 +7,27 @@ _c = request.controller
 _f = request.function
 response.title = '%s %s' % (_f, '/'.join(request.args))
 response.subtitle = 'admin'
-response.menu = [(T('site'), _f == 'site', URL(_a,'default','site'))]
+response.menu = [(T('Site'), _f == 'site', URL(_a,'default','site'))]
 
 if request.args:
     _t = request.args[0]
-    response.menu.append((T('edit'), _c == 'default' and _f == 'design',
+    response.menu.append((T('Edit'), _c == 'default' and _f == 'design',
                          URL(_a,'default','design',args=_t)))
-    response.menu.append((T('about'), _c == 'default' and _f == 'about',
+    response.menu.append((T('About'), _c == 'default' and _f == 'about',
                          URL(_a,'default','about',args=_t)))
-    response.menu.append((T('errors'), _c == 'default' and _f == 'errors',
+    response.menu.append((T('Errors'), _c == 'default' and _f == 'errors',
                          URL(_a,'default','errors',args=_t)))
-
-    response.menu.append((T('versioning'),
+    response.menu.append((T('Versioning'),
                           _c == 'mercurial' and _f == 'commit',
                           URL(_a,'mercurial','commit',args=_t)))
 
 if not session.authorized:
-    response.menu = [(T('login'), True, '')]
+    response.menu = [(T('Login'), True, '')]
 else:
-    response.menu.append((T('logout'), False,
+    response.menu.append((T('Logout'), False,
                           URL(_a,'default',f='logout')))
 
-response.menu.append((T('help'), False, URL('examples','default','index')))
-
+if os.path.exists('applications/examples'):
+    response.menu.append((T('Help'), False, URL('examples','default','index')))
+else:
+    response.menu.append((T('Help'), False, 'http://web2py.com/examples'))
