@@ -6,7 +6,8 @@
 '%s rows deleted': '%s rangées supprimées',
 '%s rows updated': '%s rangées mises à jour',
 'About': 'À propos',
-'Access Control': 'Contrôle d\'accès',
+'Access Control': "Contrôle d'accès",
+'Administrative interface': "Interface d'administration",
 'Ajax Recipes': 'Recettes Ajax',
 'Are you sure you want to delete this object?': 'Êtes-vous sûr de vouloir supprimer cet objet?',
 'Authentication': 'Authentification',
@@ -18,7 +19,7 @@
 'Client IP': 'IP client',
 'Community': 'Communauté',
 'Controller': 'Contrôleur',
-'Copyright': 'Copyright',
+'Copyright': "Droit d'auteur",
 'Current request': 'Demande actuelle',
 'Current response': 'Réponse actuelle',
 'Current session': 'Session en cours',
@@ -26,8 +27,8 @@
 'Database': 'Base de données',
 'Delete:': 'Supprimer:',
 'Demo': 'Démo',
-'Deployment Recipes': 'Recettes de déploiement',
-'Description': 'Description',
+'Deployment Recipes': 'Recettes de déploiement ',
+'Description': 'Descriptif',
 'Documentation': 'Documentation',
 'Download': 'Téléchargement',
 'E-mail': 'Courriel',
@@ -35,25 +36,28 @@
 'Edit This App': 'Modifier cette application',
 'Edit current record': "Modifier l'enregistrement courant",
 'Errors': 'Erreurs',
-'FAQ': 'FAQ',
+'FAQ': 'faq',
 'First name': 'Prénom',
 'Forms and Validators': 'Formulaires et Validateurs',
 'Free Applications': 'Applications gratuites',
 'Function disabled': 'Fonction désactivée',
+'Group %(group_id)s created': '%(group_id)s groupe créé',
 'Group ID': 'Groupe ID',
-'Groups': 'Groups',
+'Group uniquely assigned to user %(id)s': "Groupe unique attribué à l'utilisateur %(id)s",
+'Groups': 'Groupes',
 'Hello World': 'Bonjour le monde',
 'Home': 'Accueil',
 'Import/Export': 'Importer/Exporter',
 'Index': 'Index',
 'Internal State': 'État interne',
-'Introduction': 'Introduction',
+'Introduction': 'Présentation',
 'Invalid Query': 'Requête Invalide',
 'Invalid email': 'Courriel invalide',
 'Last name': 'Nom',
 'Layout': 'Mise en page',
-'Layouts': 'Layouts',
+'Layouts': 'layouts',
 'Live chat': 'Clavardage en direct',
+'Logged in': 'Connecté',
 'Login': 'Connectez-vous',
 'Lost Password': 'Mot de passe perdu',
 'Main Menu': 'Menu principal',
@@ -61,6 +65,7 @@
 'Name': 'Nom',
 'New Record': 'Nouvel enregistrement',
 'No databases in this application': "Cette application n'a pas de bases de données",
+'Online examples': 'Exemples en ligne',
 'Origin': 'Origine',
 'Other Recipes': 'Autres recettes',
 'Overview': 'Présentation',
@@ -72,10 +77,16 @@
 'Python': 'Python',
 'Query:': 'Requête:',
 'Quick Examples': 'Examples Rapides',
+'Readme': 'Lisez-moi',
 'Recipes': 'Recettes',
-'Record ID': 'ID d\'enregistrement',
+'Record %(id)s created': 'Record %(id)s created',
+'Record %(id)s updated': 'Record %(id)s updated',
+'Record Created': 'Record Created',
+'Record ID': "ID d'enregistrement",
+'Record Updated': 'Record Updated',
 'Register': "S'inscrire",
 'Registration key': "Clé d'enregistrement",
+'Registration successful': 'Inscription réussie',
 'Remember me (for 30 days)': 'Se souvenir de moi (pendant 30 jours)',
 'Request reset password': 'Demande de réinitialiser le mot clé',
 'Reset Password key': 'Réinitialiser le mot clé',
@@ -87,7 +98,7 @@
 'Services': 'Services',
 'Stylesheet': 'Feuille de style',
 'Submit': 'Soumettre',
-'Support': 'Support',
+'Support': 'Soutien',
 'Sure you want to delete this object?': 'Êtes-vous sûr de vouloir supprimer cet objet?',
 'Table name': 'Nom du tableau',
 'The "query" is a condition like "db.table1.field1==\'value\'". Something like "db.table1.field1==db.table2.field2" results in a SQL JOIN.': 'La "query" est une condition comme "db.table1.champ1==\'valeur\'". Quelque chose comme "db.table1.champ1==db.table2.champ2" résulte en un JOIN SQL.',
@@ -95,7 +106,7 @@
 'The Views': 'Les Vues',
 'The output of the file is a dictionary that was rendered by the view': 'La sortie de ce fichier est un dictionnaire qui été restitué par la vue',
 'This App': 'Cette Appli',
-'This is a copy of the scaffolding application': 'Ceci est une copie de l\'application échafaudage',
+'This is a copy of the scaffolding application': "Ceci est une copie de l'application échafaudage",
 'Timestamp': 'Horodatage',
 'Twitter': 'Twitter',
 'Update:': 'Mise à jour:',
@@ -113,23 +124,21 @@
 'Welcome to web2py': 'Bienvenue à web2py',
 'Which called the function': 'Qui a appelé la fonction',
 'You are successfully running web2py': 'Vous roulez avec succès web2py',
-'You can modify this application and adapt it to your needs': 'Vous pouvez modifier cette application et l\'adapter à vos besoins',
-'You visited the url': 'Vous avez visité l\'URL',
+'You can modify this application and adapt it to your needs': "Vous pouvez modifier cette application et l'adapter à vos besoins",
+'You visited the url': "Vous avez visité l'URL",
+'about': 'à propos',
 'appadmin is disabled because insecure channel': "appadmin est désactivée parce que le canal n'est pas sécurisé",
 'cache': 'cache',
 'change password': 'changer le mot de passe',
-'Online examples': 'Exemples en ligne',
-'Administrative interface': "Interface d'administration",
 'customize me!': 'personnalisez-moi!',
 'data uploaded': 'données téléchargées',
 'database': 'base de données',
 'database %s select': 'base de données %s select',
 'db': 'db',
 'design': 'design',
-'Documentation': 'Documentation',
 'done!': 'fait!',
 'edit profile': 'modifier le profil',
-'enter an integer between %(min)g and %(max)g': 'enter an integer between %(min)g and %(max)g',
+'enter an integer between %(min)g and %(max)g': 'entrer un entier compris entre %(min)g et %(max)g',
 'export as csv file': 'exporter sous forme de fichier csv',
 'insert new': 'insérer un nouveau',
 'insert new %s': 'insérer un nouveau %s',
@@ -142,7 +151,10 @@
 'new record inserted': 'nouvel enregistrement inséré',
 'next 100 rows': '100 prochaines lignes',
 'or import from csv file': "ou importer d'un fichier CSV",
+'password': 'mot de passe',
+'please input your password again': "S'il vous plaît entrer votre mot de passe",
 'previous 100 rows': '100 lignes précédentes',
+'profile': 'profile',
 'record': 'enregistrement',
 'record does not exist': "l'archive n'existe pas",
 'record id': "id d'enregistrement",
@@ -151,5 +163,5 @@
 'state': 'état',
 'table': 'tableau',
 'unable to parse csv file': "incapable d'analyser le fichier cvs",
-'Readme': "Lisez-moi",
+'value already in database or empty': 'valeur déjà dans la base ou vide',
 }
