@@ -13,6 +13,7 @@ FOR INTERNAL USE ONLY
 """
 
 import re
+import sys
 import fnmatch
 import os
 import copy
@@ -46,6 +47,7 @@ except:
     logger.warning('unable to import py_compile')
 
 is_gae = settings.global_settings.web2py_runtime_gae
+is_jython = settings.global_settings.is_jython = 'java' in sys.platform.lower() or hasattr(sys, 'JYTHON_JAR') or str(sys.copyright).find('Jython') > 0
 
 TEST_CODE = \
     r"""
@@ -86,15 +88,31 @@ def _TEST():
 _TEST()
 """
 
+class mybuiltin(object):
+    """
+    NOTE could simple use a dict and populate it,
+    NOTE not sure if this changes things though if monkey patching import.....
+    """
+    #__builtins__
+    def __getitem__(self, key):
+        try:
+            return getattr(__builtin__, key)
+        except AttributeError:
+            raise KeyError, key
+    def __setitem__(self, key, value):
+        setattr(self, key, value)
+
 class LoadFactory(object):
     """
     Attention: this helper is new and experimental
     """
     def __init__(self,environment):
         self.environment = environment
-    def __call__(self, c=None, f='index', args=[], vars={},
+    def __call__(self, c=None, f='index', args=None, vars=None,
                  extension=None, target=None,ajax=False,ajax_trap=False,
                  url=None,user_signature=False, content='loading...',**attr):
+        if args is None: args = []
+        vars = Storage(vars or {})
         import globals
         target = target or 'c'+str(random.random())[2:]
         attr['_id']=target
@@ -113,25 +131,34 @@ class LoadFactory(object):
                 args = [args]
             c = c or request.controller
 
-            other_request = globals.Request()
-            other_request.application = request.application
+            other_request = Storage()
+            for key, value in request.items():
+                other_request[key] = value
+            other_request['env'] = Storage()
+            for key, value in request.env.items():
+                other_request.env['key'] = value
             other_request.controller = c
             other_request.function = f
             other_request.extension = extension or request.extension
             other_request.args = List(args)
-            other_request.folder = request.folder
-            other_request.env = request.env
             other_request.vars = vars
             other_request.get_vars = vars
             other_request.post_vars = Storage()
             other_response = globals.Response()
+            other_request.env.path_info = '/' + \
+                '/'.join([request.application,c,f] + \
+                             map(str, other_request.args))
+            other_request.env.query_string = \
+                vars and html.URL(vars=vars).split('?')[1] or ''
             other_request.env.http_web2py_component_location = \
                 request.env.path_info
-            other_request.env.http_web2py_component_element = other_request.cid = target
+            other_request.cid = target
+            other_request.env.http_web2py_component_element = target
             other_response.view = '%s/%s.%s' % (c,f, other_request.extension)
-
             other_environment = copy.copy(self.environment)
             other_response._view_environment = other_environment
+            other_response.generic_patterns = \
+                copy.copy(current.response.generic_patterns)
             other_environment['request'] = other_request
             other_environment['response'] = other_response
 
@@ -213,7 +240,7 @@ OLD IMPLEMENTATION:
     return module
 """
 
-def build_environment(request, response, session):
+def build_environment(request, response, session, store_current=True):
     """
     Build the environment dictionary into which web2py files are executed.
     """
@@ -226,13 +253,20 @@ def build_environment(request, response, session):
     if not request.env:
         request.env = Storage()
 
-    current.request = request
-    current.response = response
-    current.session = session
-    current.T = environment['T'] = translator(request)
-    current.cache = environment['cache'] = Cache(request)
+    t = environment['T'] = translator(request)
+    c = environment['cache'] = Cache(request)
+    if store_current:
+        current.request = request
+        current.response = response
+        current.session = session
+        current.T = t
+        current.cache = c
 
-    __builtins__['__import__'] = __builtin__.__import__
+    global __builtins__
+    if is_jython: # jython hack
+        __builtins__ = mybuiltin()
+    else:
+        __builtins__['__import__'] = __builtin__.__import__ ### WHY?
     environment['__builtins__'] = __builtins__
     environment['HTTP'] = HTTP
     environment['redirect'] = redirect
@@ -280,7 +314,7 @@ def compile_views(folder):
     """
 
     path = os.path.join(folder, 'views')
-    for file in listdir(path, '^[\w/]+\.\w+$'):
+    for file in listdir(path, '^[\w/\-]+(\.\w+)+$'):
         data = parse_template(file, path)
         filename = ('views/%s.py' % file).replace('/', '_').replace('\\', '_')
         filename = os.path.join(folder, 'compiled', filename)
@@ -535,3 +569,5 @@ if __name__ == '__main__':
     import doctest
     doctest.testmod()
 
+
+
