@@ -13,12 +13,14 @@ import re
 import tarfile
 import glob
 import time
+import datetime
 from http import HTTP
 from gzip import open as gzopen
 from settings import global_settings
 
 
 __all__ = [
+    'parse_version',
     'read_file',
     'write_file',
     'readlines_file',
@@ -41,6 +43,14 @@ __all__ = [
     'make_fake_file_like_object',
     ]
 
+def parse_version(version = "Version 1.99.0 (2011-09-19 08:23:26)"):
+    re_version = re.compile('[^\d]+ (\d+)\.(\d+)\.(\d+)\s*\((?P<datetime>.+?)\)\s*(?P<type>[a-z]+)?')
+    m = re_version.match(version)
+    a,b,c = int(m.group(1)),int(m.group(2)),int(m.group(3)),
+    s = m.group('type') or 'dev'
+    d = datetime.datetime.strptime(m.group('datetime'),'%Y-%m-%d %H:%M:%S')
+    return (a,b,c,d,s)
+
 def read_file(filename, mode='r'):
     "returns content from filename, making sure to close the file explicitly on exit."
     f = open(filename, mode)
@@ -90,8 +100,8 @@ def listdir(
     like os.listdir() but you can specify a regex pattern to filter files.
     if add_dirs is True, the returned items will have the full path.
     """
-    if path[-1:] != '/':
-        path = path + '/'
+    if path[-1:] != os.path.sep:
+        path = path + os.path.sep
     if drop:
         n = len(path)
     else:
@@ -385,3 +395,5 @@ def make_fake_file_like_object():
             pass
     return LogFile()
 
+
+
