@@ -120,8 +120,12 @@ class HTTP(BaseException):
 
 
 def redirect(location, how=303):
+    if not location:
+        return
     location = location.replace('\r', '%0D').replace('\n', '%0A')
     raise HTTP(how,
                'You are being redirected <a href="%s">here</a>' % location,
                Location=location)
 
+
+
