@@ -95,7 +95,7 @@ class Token(object):
         if a cron job started before 60 seconds and did not stop,
         a warning is issue "Stale cron.master detected"
         """
-        if portalocker.LOCK_EX == None:
+        if portalocker.LOCK_EX is None:
             logger.warning('WEB2PY CRON: Disabled because no file locking')
             return None
         self.master = open(self.path,'rb+')
@@ -229,7 +229,7 @@ class cronlauncher(threading.Thread):
 
 def crondance(applications_parent, ctype='soft', startup=False):
     apppath = os.path.join(applications_parent,'applications')
-    cron_path = os.path.join(apppath,'admin','cron')
+    cron_path = os.path.join(applications_parent)
     token = Token(cron_path)
     cronmaster = token.acquire(startup=startup)
     if not cronmaster:
@@ -311,3 +311,5 @@ def crondance(applications_parent, ctype='soft', startup=False):
                         % (task.get('cmd'), e))
     token.release()
 
+
+
