@@ -17,7 +17,7 @@ import types
 import re
 import optparse
 import glob
-
+import traceback
 import fileutils
 import settings
 from utils import web2py_uuid
@@ -26,15 +26,16 @@ from restricted import RestrictedError
 from globals import Request, Response, Session
 from storage import Storage
 from admin import w2p_unpack
+from dal import BaseAdapter
 
 
 logger = logging.getLogger("web2py")
 
 def exec_environment(
     pyfile='',
-    request=Request(),
-    response=Response(),
-    session=Session(),
+    request=None,
+    response=None,
+    session=None,
     ):
     """
     .. function:: gluon.shell.exec_environment([pyfile=''[, request=Request()
@@ -50,6 +51,10 @@ def exec_environment(
 
     """
 
+    if request is None: request = Request()
+    if response is None: response = Response()
+    if session is None: session = Session()
+
     if request.folder is None:
         mo = re.match(r'(|.*/)applications/(?P<appname>[^/]+)', pyfile)
         if mo:
@@ -57,7 +62,7 @@ def exec_environment(
             request.folder = os.path.join('applications', appname)
         else:
             request.folder = ''
-    env = build_environment(request, response, session)
+    env = build_environment(request, response, session, store_current=False)
     if pyfile:
         pycfile = pyfile + 'c'
         if os.path.isfile(pycfile):
@@ -146,7 +151,8 @@ def run(
     plain=False,
     import_models=False,
     startfile=None,
-    bpython=False
+    bpython=False,
+    python_code=False
     ):
     """
     Start interactive shell or run Python script (startfile) in web2py
@@ -198,8 +204,18 @@ def run(
         exec_pythonrc()
         try:
             execfile(startfile, _env)
-        except RestrictedError, e:
-            print e.traceback
+            if import_models: BaseAdapter.close_all_instances('commit')
+        except Exception, e:
+            print traceback.format_exc()
+            if import_models: BaseAdapter.close_all_instances('rollback')
+    elif python_code:
+        exec_pythonrc()
+        try:
+            exec(python_code, _env)
+            if import_models: BaseAdapter.close_all_instances('commit')
+        except Exception, e:
+            print traceback.format_exc()
+            if import_models: BaseAdapter.close_all_instances('rollback')
     else:
         if not plain:
             if bpython:
@@ -213,12 +229,19 @@ def run(
             else:
                 try:
                     import IPython
-                    # following 2 lines fix a problem with IPython; thanks Michael Toomim
-                    if '__builtins__' in _env:
-                        del _env['__builtins__']
-                    shell = IPython.Shell.IPShell(argv=[], user_ns=_env)
-                    shell.mainloop()
-                    return
+                    if IPython.__version__ >= '0.11':
+                        from IPython.frontend.terminal.embed import InteractiveShellEmbed
+                        shell = InteractiveShellEmbed(user_ns=_env)
+                        shell()
+                        return
+                    else:
+                        # following 2 lines fix a problem with
+                        # IPython; thanks Michael Toomim
+                        if '__builtins__' in _env:
+                            del _env['__builtins__']
+                        shell = IPython.Shell.IPShell(argv=[],user_ns=_env)
+                        shell.mainloop()
+                        return
                 except:
                     logger.warning(
                         'import IPython error; use default python shell')
@@ -394,3 +417,5 @@ def execute_from_command_line(argv=None):
 if __name__ == '__main__':
     execute_from_command_line()
 
+
+
