@@ -61,7 +61,7 @@ class Storage(dict):
             return None
 
     def __setattr__(self, key, value):
-        if value == None:
+        if value is None:
             if key in self:
                 del self[key]
         else:
@@ -222,3 +222,5 @@ if __name__ == '__main__':
     import doctest
     doctest.testmod()
 
+
+
